This library was created for the course **IB110 - Introduction to Informatics** at [MUNI FI](https://www.fi.muni.cz/).

# Setup
The library can be installed using `pip` like so:
```pip install ib110hw_testing```

I recommend using venv to install the library as it has some dependencies.

# Modules
## Testing
The module `testing` contains some predefined strategies which can be used with the `hypothesis` library. 

## Transformation
The module `transformation` contains some implementations of some algorithms which can be used to transform automata. 
